;******************************************************************************
;(C) Copyright 2021 SuperDARN Canada, University of Saskatchewan
;
; Author: Pasha Ponomarenko (University of Saskatchewan)
;
; This program is free software: you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation, either version 3 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; For the GNU General Public License
; see <http://www.gnu.org/licenses/>.
;
; Modifications:
;
;******************************************************************************





;---------------------------------------------------------------------------
;Code for creating a two-dimensional histogram from datasets of equal size
;
;Input parameters:
;-----------------
;r1,r2                  -- input datasets (need to be of the same dimensions)
;r_st1, rst2            -- starting values
;bin_siz1, bin_siz2     -- bin sizes
;n_bins1, n_bins2       -- number of bins

;Output paramters:
;-----------------
;bin_centres1, bin_centres2 -- bin centres
;hist                       -- 2D histogram

;---------------------------------------------------------------------------

pro histo_2d,r1,r2,r_st1, r_st2, bin_siz1, bin_siz2, n_bins1, n_bins2, bin_centres1, bin_centres2, hist, plt=plt



	bin_centres1=findgen(n_bins1)*bin_siz1+r_st1

	bin_centres2=findgen(n_bins2)*bin_siz2+r_st2

	hist=lonarr(n_bins1, n_bins2)

	n1=long(n_elements(r1))

	n2=long(n_elements(r2))

	if n1 ne n2 then begin
	 print, 'Uneven number of points in two dataseries:', n1, ', ', n2
	 goto, lab_error
	endif

	for i=long(0),n_bins1-1 do begin
	 ;Selecting values inside a given bin for variable 1
	 ind1=where(r1 ge float(bin_centres1[i]) and r1 lt float(bin_centres1[i]+bin_siz1), count)
	 if count eq 0 then continue

	 ;Selecting coinciding values for variable 2
	 dr2=r2[ind1]

	   ;Distibuting the coinciding values into variable 2 bins of the 2D hisotgram:
	  for j=long(0),n_bins2-1 do begin
      ind2=where(dr2 ge float(bin_centres2[j]) and dr2 lt float(bin_centres2[j]+bin_siz2))
	    if ind2(0) ne -1 then hist[i,j]=n_elements(ind2)
	  endfor
	endfor



lab_error: err=1
end